==> php83-nextcloud-30.0.5.tgz: share/nextcloud/apps/photos/l10n/lv.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Publiskā saite",
    "Photos" : "Fotoattēli",
    "Videos" : "Video",
    "Albums" : "Albumi",
    "People" : "Cilvēki",
    "Folders" : "Mapes",
    "Favorites" : "Izlases vienumi",
    "On this day" : "Šajā dienā",
    "Shared with you" : "Koplietots ar tevi",
    "Tags" : "Birkas",
    "Places" : "Vietas",
    "Map" : "Karte",
    "Name of the album" : "Albuma nosaukums",
    "Location of the album" : "Albuma atrašanās vieta",
    "Back" : "Atpakaļ",
    "Save" : "Saglabāt",
    "Create album" : "Izveidot albumu",
    "Shared by" : "Koplietoja",
    "New album" : "Jauns albums",
    "Group" : "Grupa",
    "Copy the public link" : "Kopējiet publisko saiti",
    "Public link copied!" : "Publiskā saite nokopēta!",
    "Copy public link" : "Kopējiet publisko saiti",
    "Delete the public link" : "Dzēst publisko saiti",
    "Share via public link" : "Kopīgojiet, izmantojot publisko saiti",
    "An error occurred" : "Gadījās kļūda",
    "Favorite" : "Izlasē",
    "Go back" : "Atpakaļ",
    "Dates" : "Datumi",
    "Add folder" : "Pievienot mapi",
    "Home" : "Sākums",
    "View" : "Skats",
    "Choose the folders from where photos and videos are shown." : "Izvēlēties mapes, no kurām tiek rādīti fotoattēli un video.",
    "Choose the folder where photos and albums are uploaded to." : "Izvēlēties mapi, kurā tiek augšupielādēti fotoattēli un albumi.",
    "Edit album details" : "Labot albuma datus",
    "Rename person" : "Pārsaukt personu",
    "Remove from favorites" : "Noņemt no izlases",
    "Remove person" : "Noņemt personu",
    "Back to tags overview" : "Atpakaļ uz birku pārskatu",
    "Add" : "Pievienot",
    "Details" : "Detaļas",
    "Could not load photos folder" : "Nevarēja ielādēt fotoattēlu mapi",
    "Invalid location selected" : "Ir izvēlēta nederīga atrašanās vieta "
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");

==> php83-nextcloud-30.0.11.tgz: share/nextcloud/apps/photos/l10n/lv.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Publiskā saite",
    "Photos" : "Fotoattēli",
    "Videos" : "Video",
    "Albums" : "Albumi",
    "People" : "Cilvēki",
    "Folders" : "Mapes",
    "Favorites" : "Izlases vienumi",
    "On this day" : "Šajā dienā",
    "Shared with you" : "Koplietots ar tevi",
    "Tags" : "Birkas",
    "Places" : "Vietas",
    "Map" : "Karte",
    "Name of the album" : "Albuma nosaukums",
    "Location of the album" : "Albuma atrašanās vieta",
    "Back" : "Atpakaļ",
    "Add collaborators" : "Pievienot līdzdalībniekus",
    "Save" : "Saglabāt",
    "Create album" : "Izveidot albumu",
    "Add to Album" : "Pievienot albumam",
    "Add selection to album {albumName}" : "Pievienot atlasi albumam {albumName}",
    "Shared by" : "Koplietoja",
    "Create a new album." : "Izveidot jaunu albumu",
    "Create new album" : "Izveidot jaunu albumu",
    "New album" : "Jauns albums",
    "Group" : "Grupa",
    "Copy the public link" : "Kopējiet publisko saiti",
    "Public link copied!" : "Publiskā saite nokopēta!",
    "Copy public link" : "Kopējiet publisko saiti",
    "Delete the public link" : "Izdzēst publisko saiti",
    "Share via public link" : "Kopīgojiet, izmantojot publisko saiti",
    "An error occurred" : "Gadījās kļūda",
    "Favorite" : "Izlasē",
    "Go back" : "Atpakaļ",
    "Dates" : "Datumi",
    "_{years} year ago_::_{years} years ago_" : ["pirms {years} gadiem","pirms {years} gada","pirms {years} gadiem"],
    "Add folder" : "Pievienot mapi",
    "Home" : "Sākums",
    "View" : "Skats",
    "Choose the folders from where photos and videos are shown." : "Izvēlēties mapes, no kurām tiek rādīti fotoattēli un video.",
    "Choose the folder where photos and albums are uploaded to." : "Izvēlēties mapi, kurā tiek augšupielādēti fotoattēli un albumi.",
    "Add photos to this album" : "Pievienot šim albumam fotoattēlus",
    "Open actions menu" : "Atvērt darbību izvēlni",
    "Edit album details" : "Labot albuma datus",
    "Add photos to {albumName}" : "Pievienot {albumName} fotoattēlus",
    "Cover photo for album {albumName}" : "Albuma \"{albumName}\" vāka attēls",
    "Rename person" : "Pārdēvēt cilvēku",
    "Remove from favorites" : "Noņemt no izlases",
    "Remove person" : "Noņemt personu",
    "Cover photo for shared album {albumName}" : "Kopīgotā albuma \"{albumName}\" vāka attēls",
    "Back to tags overview" : "Atpakaļ uz birku pārskatu",
    "Add to album" : "Pievienot albumam",
    "Details" : "Detaļas",
    "Could not load photos folder" : "Nevarēja ielādēt fotoattēlu mapi",
    "Add" : "Pievienot"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
